apec module
===========

This modules contains the APEC code. It calls many different subroutines from throughout the PyAtomDB module.

It is expected (as of May 2020) that this code will go through a major rewrite to make it more pythonic and to make
many helper routines private to declutter the module. Be wary of embedding too
many links to this module in your code.

.. automodule:: pyatomdb.apec
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:
